@@ -5,8 +5,8 @@ from dataclasses import dataclass
 
 from typing_extensions import Self
 
-from nominal.core._batch_processor_proto import SerializedBatch, serialize_batch
-from nominal.core._queueing import Batch
+from nominal.core._stream.batch_processor_proto import SerializedBatch, serialize_batch
+from nominal.core._utils.queueing import Batch
 
 
 @dataclass(frozen=True)
@@ -22,11 +22,11 @@ class BatchSerializer:
         self.pool.shutdown(cancel_futures=cancel_futures)
 
     @classmethod
-    def create(cls, max_workers: int) -> Self:
+    def create(cls, max_workers: int | None) -> Self:
         pool = ProcessPoolExecutor(max_workers=max_workers)
         return cls(pool=pool)
 
-    def serialize(self, batch: Batch) -> Future[SerializedBatch]:
+    def serialize(self, batch: Batch[str | float | int]) -> Future[SerializedBatch]:
         return self.pool.submit(serialize_batch, batch)
 
     def __enter__(self) -> BatchSerializer:
